<?php

/*
 * Copyright 2008 ThinkLeft (thinkleft.com.au)
 * Copyright 2008 ProsePoint (www.prosepoint.org)
 */

module_load_include('inc', 'pp_ed', 'pp_ed.tinymce_popup');

/** Image insert wizard */

function pp_ed_insert_image_page($phase = '', $nid = null) {
  global $user;

  $title = $head = '';  
  if ($phase == 'start' || $phase == '') {
    $output = drupal_get_form('pp_ed_image_start_form');
    $title = t('Insert image');
  }
  else if ($phase == 'upload') {
    $title = t('Upload image');
    if (!module_exists('pp_image')) {
      $output = t('The ProsePoint Image module needs to be enabled to upload images.');
    } 
    elseif (!user_access('create ifimage content')) {
      $output = t('Your account does not have image uploading privileges.');      
    }
    else {
      module_load_include('inc', 'node', 'node.pages');

      $node = array('uid' => $user->uid, 'name' => (isset($user->name) ? $user->name : ''), 'type' => 'ifimage', 'language' => '');
      $output = drupal_get_form('pp_ed_image_upload_form', $node);

      // Check for any errors or drupal_set_messages' and display them
      // ToDo: Fix this up, relates to image file validation
      $errors = form_get_errors();
      if (!empty($errors)) {
      }

    }
  }
  else if ($phase == 'browse') {
    $title = t('Browse images');
    if ($view = views_get_view('images_list')) {
      $output = $view->execute_display(null);
      $view->destroy();
    }
    else {
      drupal_set_message(t('ProsePoint error: Missing view %view', array('%view' => 'images_list')), 'error');
    }
  }
  else if ($phase == 'insert') {    
    $title = $_GET['preset'] ? t('Edit inserted image node') : t('Insert image node');
    // Ensure we have a preselected node
    if (!empty($nid) && is_numeric($nid)) {
      $node = node_load(array('type' => 'ifimage', 'nid' => $nid));
    }
    if ($node->nid) {
      global $base_url;
      $head = '  <script type="text/javascript" src="' . $base_url . '/'. drupal_get_path('module', 'pp_ed') . '/plugins/pp_ed_image/js/insert.js' . '"></script>';
      $form = drupal_get_form('pp_ed_image_insert_form', $node);
      $output = '<div class="pp_ed_startover">' . l(t('Start over'), 'pp_ed/insert/ifimage/start') . '</div>'
                . $form .
                '<div><h3>'.t('Image Preview').'</h3><p id="pp_ed_img_preview">' . $node->default_image . '</p></div>';
    }
    else {
      $output = t('Invalid image selected');
    }
  }
  else if ($phase == 'url') {
    // Inserting link to an external image
    $title = $_GET['src'] ? t('Edit external image') : t('Insert external image');
    $head = '<script type="text/javascript" src="/'. drupal_get_path('module', 'pp_ed') . '/plugins/pp_ed_image/js/insert.js' . '"></script>';
    $data = new StdClass();
    $form = drupal_get_form('pp_ed_image_url_form', $data);
    $output = '<div class="pp_ed_startover">' . l(t('Start over'), 'pp_ed/insert/ifimage/start') . '</div>'
              . $form .
              '<div><h3>'.t('Image Preview').'</h3><p id="pp_ed_img_preview">' . $data->default_image . '</p></div>';
  }
  
  echo _pp_ed_tinymce_popup_wrap($title, $head, $output);
}

function pp_ed_image_start_form($form_state) {
  $form['upload'] = array(
    '#value' => '<p>' . l(t('Upload a new image'), 'pp_ed/insert/ifimage/upload') . '</p>',
  );
  $form['browse'] = array(
    '#value' => '<p>' . l(t('Browse for an image'), 'pp_ed/insert/ifimage/browse') . '</p>',
  );
  $form['url'] = array(
    '#value' => '<p>' . l(t('Show an image from another website'), 'pp_ed/insert/ifimage/url') . '</p>',
  );
  $form['cancel'] = array(
    '#value' => t('Cancel'),
    '#type' => 'submit',
    '#attributes' => array('onclick' => 'tinyMCEPopup.close(); return false;'),
  );
  return $form;
}

// The image upload form is just a wrapper around image_node_form, but with some modifications
function pp_ed_image_upload_form(&$form_state, $node) {
  global $user;
  
  $form = node_form($form_state, $node);
  // Dummy up #submit and #validate so filefield doesn't trigger a PHP warning. 
  $form['#submit'] = array();
  $form['#validate'] = array();
  content_form_alter($form, $form_state, 'ifimage_node_form');
  
  // Unset all but the essential fields
  // Rationale: If someone is inserting images while editing a story/page node, 
  //   they won't care about authorship, url aliases, menu settings et. al. 
  unset($form['revision_information']);
  unset($form['options']);

  // Some more poking
  $form['#id'] = 'pp_ed_image_upload_form';
  $form['#action'] = url($_GET['q']);
  $form['#validate'][] = 'pp_ed_image_upload_form_validate';
  $form['buttons']['submit']['#submit'] = array('pp_ed_image_upload_form_submit');
  unset($form['buttons']['preview']);

  // Fill in the author
  $form['author']['#type'] = 'value';
  $form['author']['name']['#type'] = 'value';
  $form['author']['name']['#value'] = $user->name;
  $form['author']['date']['#type'] = 'value';
  
  // $form['image']['#required'] = TRUE;
  
  // Add a cancel button
  $form['buttons']['cancel'] = array(
    '#value' => t('Cancel'),
    '#type' => 'submit',
    '#attributes' => array('onclick' => 'tinyMCEPopup.close(); return false;'),
    '#weight' => 6,
  );
  return $form;
}

function pp_ed_image_upload_form_validate($form, &$form_state) {  
  // ToDo: Make sure an image file is supplied
  node_form_validate($form, $form_state);
}

function pp_ed_image_upload_form_submit($form, &$form_state) {
  // Caution: the following may cause infinite recursion if we're not careful
  //   about what calls this function as a callback
  node_form_submit($form, $form_state);
  // Hijack the redirect to point to our own page
  $form_state['redirect'] = url('pp_ed/insert/ifimage/insert/' . $form_state['nid']);
}

function pp_ed_image_insert_form($form_state, $node) {
  $presets = pp_image_presets_select();
  $preset = array_key_exists($_GET['preset'], $presets) ? $_GET['preset'] : 'medium';
  $info = pp_image_imagefield_info($node->field_image, $preset);
  $form = array(
   '#action' => '#',
   '#attributes' => array('onsubmit' => 'pp_ed_image_insert_node(); return false;'),
  );  
  $form['nid'] = array(
    '#type' => 'hidden',
    '#value' => $node->nid,
  );
  $form['presets'] = array('#tree' => TRUE);
  foreach ($presets as $k => $file) {
    if ($k == $preset) {
      $form['presets'][$k] = array('#type' => 'hidden', '#value' => url($info['filepath']));
    }
    else {
      $each = pp_image_imagefield_info($node->field_image, $k);
      $form['presets'][$k] = array('#type' => 'hidden', '#value' => url($each['filepath']));
    }
  }
  $form['src'] = array(
    '#type' => 'hidden', '#value' => url($info['filepath']),
  );
  $form['width'] = array(
    '#type' => 'hidden', '#value' => $info['width'],
  );
  $form['height'] = array(
    '#type' => 'hidden', '#value' => $info['height'],
  );
  $form['title'] = array(
    '#title' => t('Image Title'),
    '#type' => 'textfield',
    '#description' => t('The title or name of the image'),
    '#default_value' => $_GET['title'] ? $_GET['title'] : $node->title,
  );
  $form['caption'] = array(
    '#title' => t('Caption'),
    '#type' => 'textfield',
    '#default_value' => $_GET['caption'],
  );
  $form['preset'] = array(
    '#title' => t('Size'),
    '#type' => 'select',
    '#options' => $presets,
    '#default_value' => $preset,
    '#attributes' => array('onchange' => 'pp_ed_image_insert_preview(); return false;'),
  );
  $form['alignment'] = array(
    '#title' => t('Alignment'),
    '#type' => 'radios',
    '#options' => array('none' => t('None'), 'left' => t('Left'), 'center' => t('Center'), 'right' => t('Right')),
  );
  $form['alignment']['#default_value'] = array_key_exists($_GET['align'], $form['alignment']['#options']) ? $_GET['align'] : 'none';
  $form['link'] = array(
    '#title' => t('Link Url'),
    '#type' => 'textfield',
    '#default_value' => $_GET['link'] ? $_GET['link'] : ($node->nid ? url('node/' . $node->nid) : ''),
  );
  $form['target'] = array(
    '#title' => t('Link Target'),
    '#type' => 'select',
    '#options' => array('' => t('Open in same window'), '_blank' => t('Open in new window')),
  );
  $form['target']['#default_value'] = array_key_exists($_GET['target'], $form['target']['#options']) ? $_GET['target'] : '';
  $form['teaser'] = array(
    '#title' => t('Teaser image'),
    '#type' => 'checkbox',
    '#description' => t('Show this image in the parent\'s teaser.'),
    '#default_value' => $_GET['teaser'] ? $_GET['teaser'] : '',
  );
  $form['submit'] = array(
    '#value' => t('Insert into post'),
    '#type' => 'submit',
  );
  $form['cancel'] = array(
    '#value' => t('Cancel'),
    '#type' => 'button',
    '#attributes' => array('onclick' => 'tinyMCEPopup.close(); return false;'),
  );
  $node->default_image = pp_image_render($node, $preset);
  return $form;
}


function pp_ed_image_url_form($form_state, $data) {
  $form = array(
   '#action' => '#',
   '#attributes' => array('onsubmit' => 'pp_ed_image_insert_url(); return false;'),
  );
  $form['src'] = array(
    '#title' => t('Image Url'),
    '#type' => 'textfield',
    '#description' => t('The url of the image'),
    '#attributes' => array('onblur' => 'pp_ed_image_url_preview(); return false;'),
    '#default_value' => $_GET['src'] ? $_GET['src'] : '',
  );
  $form['width'] = array(
    '#type' => 'hidden',
    '#value' => $_GET['width'] ? $_GET['width'] : '',
  );
  $form['height'] = array(
    '#type' => 'hidden',
    '#value' => $_GET['height'] ? $_GET['height'] : '',
  );
  $form['title'] = array(
    '#title' => t('Image Title'),
    '#type' => 'textfield',
    '#description' => t('The title or name of the image'),
    '#default_value' => $_GET['title'] ? $_GET['title'] : '',
  );
  $form['caption'] = array(
    '#title' => t('Caption'),
    '#type' => 'textfield',
    '#default_value' => $_GET['caption'],
  );
  $form['alignment'] = array(
    '#title' => t('Alignment'),
    '#type' => 'radios',
    '#options' => array('none' => t('None'), 'left' => t('Left'), 'center' => t('Center'), 'right' => t('Right')),    
  );
  $form['alignment']['#default_value'] = array_key_exists($_GET['align'], $form['alignment']['#options']) ? $_GET['align'] : 'none';
  $form['link'] = array(
    '#title' => t('Link Url'),
    '#type' => 'textfield',
    '#default_value' => $_GET['link'] ? $_GET['link'] : '',
  );
  $form['target'] = array(
    '#title' => t('Link Target'),
    '#type' => 'select',
    '#options' => array('' => t('Open in same window'), '_blank' => t('Open in new window')),      
  );
  $form['target']['#default_value'] = array_key_exists($_GET['target'], $form['target']['#options']) ? $_GET['target'] : '';
  $form['submit'] = array(
    '#value' => t('Insert into post'),
    '#type' => 'submit',
  );
  $form['cancel'] = array(
    '#value' => t('Cancel'),
    '#type' => 'button',
    '#attributes' => array('onclick' => 'tinyMCEPopup.close(); return false;'),
  );
  $data->default_image = '<img src="' . $_GET['src'] . '"></a></p>';
  
  return $form;
}




